6.0.0
  - breaking change: update httpx dependency to 0.28.0

5.1.0
  - added `reset_metrics` API method
  - updated docs

5.0.2
  - fix config

5.0.1
  - updated config file
  - expanded dependency range

5.0.0
  - breaking change: update httpx dependency to 0.27.0

4.0.1
  - fix broken release

4.0.0
  - breaking change: change modules naming method
  - breaking change: migrate to Python 3.8
  - synchronized with JavaScript SDK 3.5.3

3.3.1
  - update docs and setup.py

3.3.0
  - updated dependencies

3.2.2
  - update package info

3.2.1
  - fix faq url

3.2.0
  - added riskInBalancePercent metric to trades and open trades
  - added riskInPips metric to trades and open trades

3.1.2
  - fixed dependency vulnerabilities

3.1.1
  - added references to MT manager api and risk management api

3.1.0
  - added region support
  - breaking change: changed default value for update_history parameter get_account_trades method
  - improved readme and examples

2.0.0
  - added getAccountTrades method
  - added getAccountOpenTrades method
  - added freeMargin metric
  - added margin metric
  - added marginLevel metric
  - added cagr metric
  - added mar metric

1.0.4
  - updated dependencies

1.0.3
  - documentation clarifications for some metrics

1.0.0
  - Implemented MetaStats SDK
